==> nextcloud-app-spreed-1%3A8.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/eo.js <==
OC.L10N.register(
    "spreed",
    {
    "Talk" : "Paroli",
    "Guest" : "Gasto",
    "Talk to %s" : "Paroli al %s",
    "Invalid date, date format must be YYYY-MM-DD" : "Nevalida dato; datoformo estu JJJJ-MM-TT",
    "None" : "Nenio",
    "User" : "Uzanto",
    "Everyone" : "Ĉiuj",
    "Disabled" : "Malŝaltita",
    "Users" : "Uzantoj",
    "Copy link" : "Kopii ligilon",
    "Favorite" : "Pliŝatata",
    "Remove from favorites" : "Forigi el pliŝataĵoj",
    "Add to favorites" : "Aldoni al pliŝataĵoj",
    "Contacts" : "Kontaktoj",
    "Groups" : "Grupoj",
    "Circles" : "Rondoj",
    "Loading" : "Ŝargado",
    "Error" : "Eraro",
    "Password protect" : "Protekti per pasvorto",
    "Back" : "Antaŭen",
    "Close" : "Malfermi",
    "Reply" : "Respondi",
    "Today" : "Hodiaŭ",
    "Yesterday" : "Hieraŭ",
    "guest" : "gasto",
    "No results" : "Neniu rezulto",
    "Guests" : "Gastoj",
    "Share link" : "Kunhavigi ligilon",
    "Password protection" : "Protektita per pasvorto",
    "Enter a password" : "Entajpu pasvorton",
    "Chat" : "Babili",
    "Edit" : "Modifi",
    "Limit to groups" : "Limigi al grupoj",
    "Save changes" : "Konservi ŝanĝojn",
    "Saving …" : "Konservado...",
    "Saved!" : "Konservita!",
    "Beta" : "Beta",
    "Name" : "Nomo",
    "Saved" : "Konservita",
    "Password required" : "Pasvorto bezonata",
    "Password" : "Pasvorto",
    "Cancel" : "Nuligi",
    "Submit" : "Sendi",
    "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
    "Android app" : "Android-aplikaĵo",
    "iOS app" : "iOS-aplikaĵo",
    "Copy" : "Kopii",
    "Copied!" : "Kopiita!",
    "Not supported!" : "Ne subtenite!",
    "Press ⌘-C to copy." : "Premu ⌘-C por kopii.",
    "Press Ctrl-C to copy." : "Premu Ctrl-C por kopii.",
    "Share" : "Kunhavigi",
    "Change password" : "Ŝanĝi la pasvorton",
    "Set password" : "Uzi pasvorton",
    "Rename" : "Alinomi",
    "You" : "Vi",
    "Send" : "Sendi",
    "Error while sharing" : "Eraro dum kunhavigo",
    "Favorited" : "Pliŝatitaj",
    ", " : ", "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A9.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/eo.js <==
OC.L10N.register(
    "spreed",
    {
    "Talk" : "Paroli",
    "Guest" : "Gasto",
    "Talk to %s" : "Paroli al %s",
    "Invalid date, date format must be YYYY-MM-DD" : "Nevalida dato; datoformo estu JJJJ-MM-TT",
    "Limit to groups" : "Limigi al grupoj",
    "Everyone" : "Ĉiuj",
    "Save changes" : "Konservi ŝanĝojn",
    "Saving …" : "Konservado...",
    "Saved!" : "Konservita!",
    "None" : "Nenio",
    "User" : "Uzanto",
    "Disabled" : "Malŝaltita",
    "Users" : "Uzantoj",
    "Beta" : "Beta",
    "Name" : "Nomo",
    "Saved" : "Konservita",
    "Copy link" : "Kopii ligilon",
    "Favorite" : "Pliŝatata",
    "Remove from favorites" : "Forigi el pliŝataĵoj",
    "Add to favorites" : "Aldoni al pliŝataĵoj",
    "Contacts" : "Kontaktoj",
    "Loading" : "Ŝargado",
    "Groups" : "Grupoj",
    "Circles" : "Rondoj",
    "Error" : "Eraro",
    "Password protect" : "Protekti per pasvorto",
    "Back" : "Antaŭen",
    "Close" : "Malfermi",
    "Reply" : "Respondi",
    "Today" : "Hodiaŭ",
    "Yesterday" : "Hieraŭ",
    "guest" : "gasto",
    "No results" : "Neniu rezulto",
    "Chat" : "Babili",
    "Settings" : "Agordoj",
    "Edit" : "Modifi",
    "Dismiss" : "Preterpasi",
    "Share link" : "Kunhavigi ligilon",
    "Password protection" : "Protektita per pasvorto",
    "Enter a password" : "Entajpu pasvorton",
    "Grid view" : "Krada vido",
    "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
    "Password" : "Pasvorto",
    "Android app" : "Android-aplikaĵo",
    "iOS app" : "iOS-aplikaĵo",
    "Copy" : "Kopii",
    "Copied!" : "Kopiita!",
    "Not supported!" : "Ne subtenite!",
    "Press ⌘-C to copy." : "Premu ⌘-C por kopii.",
    "Press Ctrl-C to copy." : "Premu Ctrl-C por kopii.",
    "Password required" : "Pasvorto bezonata",
    "Cancel" : "Nuligi",
    "Submit" : "Sendi",
    "Guests" : "Gastoj",
    "Change password" : "Ŝanĝi la pasvorton",
    "Set password" : "Uzi pasvorton",
    "Rename" : "Alinomi",
    "You" : "Vi",
    "Send" : "Sendi",
    "Share" : "Kunhavigi",
    "Error while sharing" : "Eraro dum kunhavigo",
    "Favorited" : "Pliŝatitaj"
},
"nplurals=2; plural=(n != 1);");
